@@ -7,14 +7,14 @@
 static ESTRUC_
     frame;
 
-ESTRUC_ stackframe(E_TYPE_ type)
+ESTRUC_ *stackframe(E_TYPE_ type)
 {
     frame.type = type;
 
     switch (type)
     {
         case e_int | e_const:
-            frame.evalue = atoi(string);
+            frame.evalue = atoi(lexstring);
         break;
 
         case e_str | e_const:
@@ -25,5 +25,5 @@ ESTRUC_ stackframe(E_TYPE_ type)
             frame.evalue = 0;
     }
 
-    return (frame);
+    return &frame;
 }
